@@ -1,7 +1,10 @@
 from aif360.algorithms.inprocessing.adversarial_debiasing import AdversarialDebiasing
-from generate_binary_dataset import generate_binary_label_dataset
+from aif360.datasets.binary_label_dataset import BinaryLabelDataset
 import tensorflow as tf
 
+def generate_binary_label_dataset(df, label, protected_attribute, favorable_label, unfavorable_label):
+    return BinaryLabelDataset(unfavorable_label, favorable_label, df=df, label_names=[label], protected_attribute_names=[protected_attribute])
+
 class Fair_Model():
     def __init__(self, unprivileged_groups, privileged_groups, label, protected_attribute, favorable_label, unfavorable_label):
         self.sess = tf.Session()
